==> google-cloud-sdk-325.0.0.txz: usr/local/google-cloud-sdk/lib/surface/resource_manager/tags/keys/create.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create command for the Resource Manager - Tag Keys CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.resource_manager import tags
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.resource_manager import operations
from googlecloudsdk.command_lib.resource_manager import tag_arguments as arguments


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Create(base.Command):
  r"""Creates a TagKey resource under the specified tag parent.

  ## EXAMPLES

  To create a TagKey with the name env under 'organizations/123' with
  description 'description', run:

        $ {command} env --parent='organizations/123'
        --description='description'
  """

  @staticmethod
  def Args(parser):
    group = parser.add_argument_group('TagKey.', required=True)
    arguments.AddShortNameArgToParser(group)
    arguments.AddParentArgToParser(group, required=True)
    arguments.AddDescriptionArgToParser(parser)
    arguments.AddAsyncArgToParser(parser)

  def Run(self, args):
    service = tags.TagKeysService()
    messages = tags.TagMessages()

    short_name = args.short_name
    tag_parent = args.parent
    description = args.description

    tag_key = messages.TagKey(
        shortName=short_name, parent=tag_parent, description=description)
    create_req = messages.CloudresourcemanagerTagKeysCreateRequest(
        tagKey=tag_key)
    op = service.Create(create_req)

    if args.async_ or op.done:
      return op
    else:
      done_op = operations.WaitForOperation(
          op,
          'Waiting for TagKey [{}] to be created with [{}]'.format(
              short_name, op.name),
          service=service)
      return done_op

==> google-cloud-sdk-329.0.0.txz: usr/local/google-cloud-sdk/lib/surface/resource_manager/tags/keys/create.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create command for the Resource Manager - Tag Keys CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.resource_manager import tags
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.resource_manager import operations
from googlecloudsdk.command_lib.resource_manager import tag_arguments as arguments


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Create(base.Command):
  r"""Creates a TagKey resource under the specified tag parent.

  ## EXAMPLES

  To create a TagKey with the name env under 'organizations/123' with
  description 'description', run:

        $ {command} env --parent=organizations/123
        --description=description
  """

  @staticmethod
  def Args(parser):
    group = parser.add_argument_group("TagKey.", required=True)
    arguments.AddShortNameArgToParser(group)
    arguments.AddParentArgToParser(
        group,
        message="Parent of the TagKey in the form of organizations/{org_id}.")
    arguments.AddDescriptionArgToParser(parser)
    arguments.AddAsyncArgToParser(parser)

  def Run(self, args):
    service = tags.TagKeysService()
    messages = tags.TagMessages()

    short_name = args.short_name
    tag_parent = args.parent
    description = args.description

    tag_key = messages.TagKey(
        shortName=short_name, parent=tag_parent, description=description)
    create_req = messages.CloudresourcemanagerTagKeysCreateRequest(
        tagKey=tag_key)
    op = service.Create(create_req)

    if args.async_:
      return op

    return operations.WaitForOperation(
        op,
        "Waiting for TagKey [{}] to be created".format(short_name),
        service=service)
